@@ -17,6 +17,7 @@
  */
 
 #include "config.h"
+#include <stdint.h>
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <netdb.h>
@@ -44,10 +45,19 @@
 #define ICMP6_ECHO_LEN		8	/* from FreeBSD's ping6.c */
 #define ICMP6_PACKET_LEN	(ICMP6_ECHO_LEN + sizeof(LMICMPData))
 
-/* these ICMPv6 types are not defined by all platforms yet */
+/* these ICMPv6 types are not defined by all platforms */
 #ifndef ICMP6_DST_UNREACH_BEYONDSCOPE
 #define ICMP6_DST_UNREACH_BEYONDSCOPE	2	/* RFC 3542 */
 #endif
+#ifndef ICMP6_MEMBERSHIP_QUERY
+#define ICMP6_MEMBERSHIP_QUERY		130
+#endif
+#ifndef ICMP6_MEMBERSHIP_REPORT
+#define ICMP6_MEMBERSHIP_REPORT		131
+#endif
+#ifndef ICMP6_MEMBERSHIP_REDUCTION
+#define ICMP6_MEMBERSHIP_REDUCTION	132
+#endif
 #ifndef ICMP6_NI_QUERY
 #define ICMP6_NI_QUERY			139
 #endif
